@@ -2,7 +2,8 @@ from llm_foundation import logger
 
 
 def main():
-    logger.info(f"Hello World!")
+    logger.info(f"Hello World from LLM_Foundation!")
+
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
